@@ -8,11 +8,14 @@ MODULES=(
   "github.com/kovidgoyal/dbus"
   "github.com/kovidgoyal/imaging"
   "github.com/kovidgoyal/go-parallel"
+  "github.com/kovidgoyal/go-shm"
+  "github.com/hako/durafmt"
 )
 
 # Loop through each module
 for MODULE in "${MODULES[@]}"
 do
+  rm -rf debian/vendor/"$MODULE"
   mkdir -p debian/vendor/"$MODULE"
   cp --archive --update --verbose vendor/"$MODULE"/* debian/vendor/"$MODULE"/
   rm -rf vendor/"$MODULE"
